/*
 * SPDX-License-Identifier: Apache-2.0
 */

"use strict";

const { FileSystemWallet, Gateway } = require("fabric-network");
const path = require("path");

const ccpPath = path.resolve(
  __dirname,
  "..",
  "network",
  "connection-org1.json"
);

async function query(user, functionName, queryJSON) {
  try {
    // Create a new file system based wallet for managing identities.
    const walletPath = path.join(process.cwd(), "wallet");
    const wallet = new FileSystemWallet(walletPath);

    // Check to see if we've already enrolled the user.
    const userExists = await wallet.exists(user);
    if (!userExists) {
      console.log(
        "An identity for the user " + user + " does not exist in the wallet"
      );
      console.log("Run the registerUser.js application before retrying");
      return;
    }

    // Create a new gateway for connecting to our peer node.
    const gateway = new Gateway();
    await gateway.connect(ccpPath, {
      wallet,
      identity: user,
      discovery: { enabled: true, asLocalhost: true }
    });

    // Get the network (channel) our contract is deployed to.
    const network = await gateway.getNetwork("mychannel");

    // Get the contract from the network.
    const contract = network.getContract("edjx");

    // Evaluate the specified transaction.
    let result;
    if (queryJSON) {
      result = await contract.evaluateTransaction(
        functionName,
        JSON.stringify(queryJSON)
      );
    } else {
      result = await contract.evaluateTransaction(functionName);
    }

    console.log(
      `Transaction has been evaluated, result is: ${result.toString()}`
    );
    return result.toString();
  } catch (error) {
    console.error(`Failed to evaluate transaction: ${error}`);
    return error;
  }
}

// query("user2");
module.exports = query;
