const axios = require("axios");
const expect = require("chai").expect;
const _ = require("lodash");
const nanoid = require("nanoid");
const log4js = require("log4js");
const logger = log4js.getLogger("App-test");
describe("App api ", async function() {
  this.timeout(45000);
  let uid = "app" + Math.random() * 1000;
  let xAccessToken;
  let payloadCreate = {
    applicationId: uid,
    objectType: "Application",
    Name: "app1",
    Status: "up"
  };

  let payloadUpdate = {
    applicationId: uid,
    Name: "app1",
    Status: "down"
  };

  afterEach(function(done) {
    setTimeout(function() {
      done();
    }, 30000);
  });
  before(async () => {
    try {
      const email = `app${nanoid()}@fakeemail.com;`;
      await axios({
        method: "post",
        url: "http://localhost:3000/users/register",
        data: {
          email,
          password: "p@ssw0rd",
          org: "org1",
          role: "consumer"
        },
        headers: {
          "content-type": "application/json"
        }
      });
      let response = await axios({
        method: "post",
        url: "http://localhost:3000/users/login",
        data: {
          email,
          password: "p@ssw0rd",
          org: "org1"
        },
        headers: {
          "content-type": "application/json"
        }
      });
      xAccessToken = response.data.accessToken;
    } catch (error) {
      logger.error(error);
    }
  });

  it("Creates App", async function() {
    const response = await axios({
      method: "post",
      url: "http://localhost:3000/applications",
      data: payloadCreate,
      json: true,
      headers: {
        "content-type": "application/json",
        "x-access-token": xAccessToken
      }
    });
    let data = JSON.parse(response.data.objectBytes);
    delete data.OwnerID;
    delete payloadCreate.OwnerID;

    payloadCreate.objectType = "Application";
    expect(response.status).to.be.equal(200);
  });

  it("Updates App", async function() {
    const response = await axios({
      method: "put",
      url: `http://localhost:3000/applications/${uid}`,
      data: payloadUpdate,
      json: true,
      headers: {
        "content-type": "application/json",
        "x-access-token": xAccessToken
      }
    });
    payloadUpdate.objectType = "Application";
    expect(response.status).to.be.equal(200);
  });

  it("Gets a App by id", async function() {
    const response = await axios({
      method: "get",
      url: `http://localhost:3000/applications/${uid}`,
      headers: {
        "content-type": "application/json",
        "x-access-token": xAccessToken
      }
    });
    payloadUpdate.objectType = "Application";
    expect(response.status).to.be.equal(200);
  });

  it("Gets all Apps", async function() {
    const response = await axios({
      method: "get",
      url: "http://localhost:3000/applications",
      headers: {
        "content-type": "application/json",
        "x-access-token": xAccessToken
      }
    });
    expect(response.status).to.be.equal(200);
  });

  it("Deletes App", async function() {
    const response = await axios({
      method: "delete",
      url: `http://localhost:3000/applications/${uid}`,
      headers: {
        "content-type": "application/json",
        "x-access-token": xAccessToken
      }
    });
    expect(response.status).to.be.equal(200);
    expect(response.data.objectBytes).to.be.equal("");
  });
});
