const axios = require("axios");
const expect = require("chai").expect;
const _ = require("lodash");
const nanoid = require("nanoid");
const log4js = require("log4js");
const logger = log4js.getLogger("Function-test");
describe("Function api ", async function() {
  this.timeout(45000);
  let xAccessToken;
  let payloadCreate = {
    functionId: "function1",
    applicationId: "commodo velit tempor",
    Name: "aute dolor eu ipsum magna",
    BundleURL: "culpa ex",
    BundleHash: "ad tempor aliqua",
    Status: "veniam"
  };
  let payloadUpdate = {
    applicationId: "consectetur veniam cupidatat ut",
    Name: "velit mollit officia",
    BundleURL: "cillum Ut incididunt nulla",
    BundleHash: "consect",
    Status: "veniam Excepteur irure"
  };
  afterEach(function(done) {
    setTimeout(function() {
      done();
    }, 30000);
  });
  before(async () => {
    try {
      const email = `function${nanoid()}@fakeemail.com;`;
      await axios({
        method: "post",
        url: "http://localhost:3000/users/register",
        data: {
          email,
          password: "p@ssw0rd",
          org: "org1",
          role: "consumer"
        },
        headers: {
          "content-type": "application/json"
        }
      });
      let response = await axios({
        method: "post",
        url: "http://localhost:3000/users/login",
        data: {
          email,
          password: "p@ssw0rd",
          org: "org1"
        },
        headers: {
          "content-type": "application/json"
        }
      });
      xAccessToken = response.data.accessToken;
    } catch (error) {
      logger.error(error);
    }
  });

  it("Creates Function", async function() {
    const response = await axios({
      method: "post",
      url: "http://localhost:3000/functions",
      data: payloadCreate,
      json: true,
      headers: {
        "content-type": "application/json",
        "x-access-token": xAccessToken
      }
    });
    let data = JSON.parse(response.data.objectBytes);
    delete data.OwnerID;
    delete payloadCreate.OwnerID;
    payloadCreate.objectType = "Function";
    expect(response.status).to.be.equal(200);
  });

  it("Updates Function", async function() {
    const response = await axios({
      method: "put",
      url: "http://localhost:3000/functions/function1",
      data: payloadUpdate,
      json: true,
      headers: {
        "content-type": "application/json",
        "x-access-token": xAccessToken
      }
    });
    payloadUpdate.objectType = "Function";
    expect(response.status).to.be.equal(200);
  });

  it("Gets a Function by id", async function() {
    const response = await axios({
      method: "get",
      url: "http://localhost:3000/functions/function1",
      headers: {
        "content-type": "application/json",
        "x-access-token": xAccessToken
      }
    });
    payloadUpdate.objectType = "Function";
    expect(response.status).to.be.equal(200);
  });

  it("Gets all Functions", async function() {
    const response = await axios({
      method: "get",
      url: "http://localhost:3000/functions",
      headers: {
        "content-type": "application/json",
        "x-access-token": xAccessToken
      }
    });
    expect(response.status).to.be.equal(200);
  });

  it("Deletes Function", async function() {
    const response = await axios({
      method: "delete",
      url: "http://localhost:3000/functions/function1",
      headers: {
        "content-type": "application/json",
        "x-access-token": xAccessToken
      }
    });
    expect(response.status).to.be.equal(200);
    expect(response.data.objectBytes).to.be.equal("");
  });
});
