const axios = require("axios");
const expect = require("chai").expect;
const _ = require("lodash");
const nanoid = require("nanoid");
const log4js = require("log4js");
const logger = log4js.getLogger("Node-test");
describe("Node api ", async function() {
  this.timeout(45000);
  let xAccessToken;
  let uid = "node" + Math.random() * 1000;
  let payloadCreate = {
    nodeId: uid,
    Name: "Ut commodo re",
    Sockets: 2,
    Cores: 8,
    MemoryBytes: 1098766,
    StorageBytes: 837665,
    Status: "aliquip minim irure"
  };
  let payloadUpdate = {
    nodeId: uid,
    Name: "sunt mollit minim",
    Sockets: 2,
    Cores: 8,
    MemoryBytes: 1098766,
    StorageBytes: 837665,
    Status: "ea esse"
  };
  afterEach(function(done) {
    setTimeout(function() {
      done();
    }, 30000);
  });
  before(async () => {
    try {
      const email = `node${nanoid()}@fakeemail.com;`;
      await axios({
        method: "post",
        url: "http://localhost:3000/users/register",
        data: {
          email,
          password: "p@ssw0rd",
          org: "org1",
          role: "producer"
        },
        headers: {
          "content-type": "application/json"
        }
      });
      let response = await axios({
        method: "post",
        url: "http://localhost:3000/users/login",
        data: {
          email,
          password: "p@ssw0rd",
          org: "org1"
        },
        headers: {
          "content-type": "application/json"
        }
      });
      xAccessToken = response.data.accessToken;
    } catch (error) {
      logger.error(error);
    }
  });

  it("Creates Node", async function() {
    const response = await axios({
      method: "post",
      url: "http://localhost:3000/nodes",
      data: payloadCreate,
      json: true,
      headers: {
        "content-type": "application/json",
        "x-access-token": xAccessToken
      }
    });
    payloadCreate.objectType = "Node";
    expect(response.status).to.be.equal(200);
  });

  it("Updates Node", async function() {
    const response = await axios({
      method: "put",
      url: `http://localhost:3000/nodes/${uid}`,
      data: payloadUpdate,
      json: true,
      headers: {
        "content-type": "application/json",
        "x-access-token": xAccessToken
      }
    });

    let data = JSON.parse(response.data.objectBytes);
    delete data.OwnerID;
    delete payloadCreate.OwnerID;
    payloadUpdate.objectType = "Node";
    expect(response.status).to.be.equal(200);
  });

  it("Gets a Node by id", async function() {
    const response = await axios({
      method: "get",
      url: `http://localhost:3000/nodes/${uid}`,
      headers: {
        "content-type": "application/json",
        "x-access-token": xAccessToken
      }
    });
    payloadUpdate.objectType = "Node";
    expect(response.status).to.be.equal(200);
  });

  it("Gets all Nodes", async function() {
    const response = await axios({
      method: "get",
      url: "http://localhost:3000/nodes",
      headers: {
        "content-type": "application/json",
        "x-access-token": xAccessToken
      }
    });
    expect(response.status).to.be.equal(200);
  });

  it("Deletes Node", async function() {
    const response = await axios({
      method: "delete",
      url: `http://localhost:3000/nodes/${uid}`,
      headers: {
        "content-type": "application/json",
        "x-access-token": xAccessToken
      }
    });
    expect(response.status).to.be.equal(200);
    expect(response.data.objectBytes).to.be.equal("");
  });
});
