const axios = require("axios");
const expect = require("chai").expect;
const _ = require("lodash");
const nanoid = require("nanoid");
const log4js = require("log4js");
const logger = log4js.getLogger("Request-test");
describe("Request api ", async function() {
  this.timeout(3000);
  let xAccessToken;
  let payloadCreate = {
    requestId: "2e9bc362-ff37-4236-97e0-6280999f0abd",
    functionId: "eu",
    RequesterID: "commodo voluptate",
    ExecutorID: "exer",
    nodeId: "adipisicing velit tempor in labore",
    ExecutionSecs: 120,
    MemoryBytes: 1609876,
    NetworkBytes: 76655,
    LogURL: "reprehenderit ipsum enim dolor",
    LogHash: "anim"
  };
  let payloadUpdate = {
    requestId: "2e9bc362-ff37-4236-97e0-6280999f0abd",
    functionId: "minim anim non ad",
    RequesterID: "ea esse",
    ExecutorID: "Duis laboris",
    nodeId: "cillum proident sunt adipisicing pariatur",
    ExecutionSecs: 120,
    MemoryBytes: 1609876,
    NetworkBytes: 76655,
    LogURL: "occaecat qui",
    LogHash: "veniam ipsum "
  };
  afterEach(function(done) {
    setTimeout(function() {
      done();
    }, 3000);
  });
  before(async () => {
    try {
      const email = `request${nanoid()}@fakeemail.com;`;
      await axios({
        method: "post",
        url: "http://localhost:3000/users/register",
        data: {
          email,
          password: "p@ssw0rd",
          org: "org1",
          role: "Consumer"
        },
        headers: {
          "content-type": "application/json"
        }
      });
      let response = await axios({
        method: "post",
        url: "http://localhost:3000/users/login",
        data: {
          email,
          password: "p@ssw0rd",
          org: "org1"
        },
        headers: {
          "content-type": "application/json"
        }
      });
      xAccessToken = response.data.accessToken;
    } catch (error) {
      logger.error(error);
    }
  });

  it("Creates Request", async function() {
    const response = await axios({
      method: "post",
      url: "http://localhost:3000/request",
      data: payloadCreate,
      json: true,
      headers: {
        "content-type": "application/json",
        "x-access-token": xAccessToken
      }
    });
    payloadCreate.objectType = "Request";
    expect(response.status).to.be.equal(200);
    expect(payloadCreate).to.be.deep.equal(
      JSON.parse(response.data.objectBytes)
    );
  });

  it("Updates Request", async function() {
    const response = await axios({
      method: "put",
      url: "http://localhost:3000/request",
      data: payloadUpdate,
      json: true,
      headers: {
        "content-type": "application/json",
        "x-access-token": xAccessToken
      }
    });
    payloadUpdate.objectType = "Request";
    expect(response.status).to.be.equal(200);
    expect(payloadUpdate).to.be.deep.equal(
      JSON.parse(response.data.objectBytes)
    );
  });

  it("Gets a Request by id", async function() {
    const response = await axios({
      method: "get",
      url: "http://localhost:3000/request/2e9bc362-ff37-4236-97e0-6280999f0abd",
      headers: {
        "content-type": "application/json",
        "x-access-token": xAccessToken
      }
    });
    payloadUpdate.objectType = "Request";
    expect(response.status).to.be.equal(200);
    expect(payloadUpdate).to.be.deep.equal(
      JSON.parse(response.data.objectBytes)
    );
  });

  it("Gets all Requests", async function() {
    const response = await axios({
      method: "get",
      url: "http://localhost:3000/requestlist",
      headers: {
        "content-type": "application/json",
        "x-access-token": xAccessToken
      }
    });
    expect(response.status).to.be.equal(200);
    expect(JSON.parse(response.data.objectBytes)).to.deep.include(
      payloadUpdate
    );
  });

  it("Deletes Request", async function() {
    const response = await axios({
      method: "delete",
      url: "http://localhost:3000/request/2e9bc362-ff37-4236-97e0-6280999f0abd",
      headers: {
        "content-type": "application/json",
        "x-access-token": xAccessToken
      }
    });
    expect(response.status).to.be.equal(200);
    expect(response.data.objectBytes).to.be.equal("");
  });
});
